#include <libint2.h>
#include <GenericContract.h>
#include <OSVRRP0InBra_aB_p__0__k__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP0InBra_aB_p__0__l__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP0InBra_aB_p__0__m__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP0InBra_aB_p__0__pd__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP0InBra_aB_p__0__pf__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP0InBra_aB_p__0__pp__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP0InBra_aB_p__0__ps__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__g__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__h__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__i__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__k__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__l__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__m__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__pd__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__pf__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__pp__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__ps__1___TwoPRep_s__0__s__1___Ab__up_0.h>

#ifdef __cplusplus
extern "C" {
#endif
void _aB_P__0__K__1___TwoPRep_S__0__I__1___Ab__up_0_prereq(const Libint_t* inteval, LIBINT2_REALTYPE* parent_stack) {

LIBINT2_REALTYPE*const  stack = parent_stack;
{
const int hsi = 0;
{
const int lsi = 0;
{
const int vi = 0;
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+1428)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_4[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_5[vi]));
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+1431)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_3[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_4[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+1434)*1+lsi)*1]), &(stack[((hsi*3+1431)*1+lsi)*1]), &(stack[((hsi*3+1428)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_3[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_4[vi]));
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+1440)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_2[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_3[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+1443)*1+lsi)*1]), &(stack[((hsi*3+1440)*1+lsi)*1]), &(stack[((hsi*3+1431)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_2[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_3[vi]));
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+1449)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_5[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_6[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+1452)*1+lsi)*1]), &(stack[((hsi*3+1428)*1+lsi)*1]), &(stack[((hsi*3+1449)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_4[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_5[vi]));
OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*10+1458)*1+lsi)*1]), &(stack[((hsi*6+1434)*1+lsi)*1]), &(stack[((hsi*6+1452)*1+lsi)*1]), &(stack[((hsi*3+1431)*1+lsi)*1]), &(stack[((hsi*3+1428)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*10+1468)*1+lsi)*1]), &(stack[((hsi*6+1443)*1+lsi)*1]), &(stack[((hsi*6+1434)*1+lsi)*1]), &(stack[((hsi*3+1440)*1+lsi)*1]), &(stack[((hsi*3+1431)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__g__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*15+1478)*1+lsi)*1]), &(stack[((hsi*10+1468)*1+lsi)*1]), &(stack[((hsi*10+1458)*1+lsi)*1]), &(stack[((hsi*6+1443)*1+lsi)*1]), &(stack[((hsi*6+1434)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+1431)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_1[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_2[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+1493)*1+lsi)*1]), &(stack[((hsi*3+1431)*1+lsi)*1]), &(stack[((hsi*3+1440)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_1[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_2[vi]));
OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*10+1499)*1+lsi)*1]), &(stack[((hsi*6+1493)*1+lsi)*1]), &(stack[((hsi*6+1443)*1+lsi)*1]), &(stack[((hsi*3+1431)*1+lsi)*1]), &(stack[((hsi*3+1440)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__g__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*15+1509)*1+lsi)*1]), &(stack[((hsi*10+1499)*1+lsi)*1]), &(stack[((hsi*10+1468)*1+lsi)*1]), &(stack[((hsi*6+1493)*1+lsi)*1]), &(stack[((hsi*6+1443)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+1440)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_6[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_7[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+1443)*1+lsi)*1]), &(stack[((hsi*3+1449)*1+lsi)*1]), &(stack[((hsi*3+1440)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_5[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_6[vi]));
OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*10+1524)*1+lsi)*1]), &(stack[((hsi*6+1452)*1+lsi)*1]), &(stack[((hsi*6+1443)*1+lsi)*1]), &(stack[((hsi*3+1428)*1+lsi)*1]), &(stack[((hsi*3+1449)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__g__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*15+1534)*1+lsi)*1]), &(stack[((hsi*10+1458)*1+lsi)*1]), &(stack[((hsi*10+1524)*1+lsi)*1]), &(stack[((hsi*6+1434)*1+lsi)*1]), &(stack[((hsi*6+1452)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__h__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*21+1549)*1+lsi)*1]), &(stack[((hsi*15+1478)*1+lsi)*1]), &(stack[((hsi*15+1534)*1+lsi)*1]), &(stack[((hsi*10+1468)*1+lsi)*1]), &(stack[((hsi*10+1458)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__h__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*21+1570)*1+lsi)*1]), &(stack[((hsi*15+1509)*1+lsi)*1]), &(stack[((hsi*15+1478)*1+lsi)*1]), &(stack[((hsi*10+1499)*1+lsi)*1]), &(stack[((hsi*10+1468)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__i__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*28+1591)*1+lsi)*1]), &(stack[((hsi*21+1570)*1+lsi)*1]), &(stack[((hsi*21+1549)*1+lsi)*1]), &(stack[((hsi*15+1509)*1+lsi)*1]), &(stack[((hsi*15+1478)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+1428)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_7[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_8[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+1434)*1+lsi)*1]), &(stack[((hsi*3+1440)*1+lsi)*1]), &(stack[((hsi*3+1428)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_6[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_7[vi]));
OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*10+1468)*1+lsi)*1]), &(stack[((hsi*6+1443)*1+lsi)*1]), &(stack[((hsi*6+1434)*1+lsi)*1]), &(stack[((hsi*3+1449)*1+lsi)*1]), &(stack[((hsi*3+1440)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__g__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*15+1619)*1+lsi)*1]), &(stack[((hsi*10+1524)*1+lsi)*1]), &(stack[((hsi*10+1468)*1+lsi)*1]), &(stack[((hsi*6+1452)*1+lsi)*1]), &(stack[((hsi*6+1443)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__h__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*21+1634)*1+lsi)*1]), &(stack[((hsi*15+1534)*1+lsi)*1]), &(stack[((hsi*15+1619)*1+lsi)*1]), &(stack[((hsi*10+1458)*1+lsi)*1]), &(stack[((hsi*10+1524)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__i__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*28+1655)*1+lsi)*1]), &(stack[((hsi*21+1549)*1+lsi)*1]), &(stack[((hsi*21+1634)*1+lsi)*1]), &(stack[((hsi*15+1478)*1+lsi)*1]), &(stack[((hsi*15+1534)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__k__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*36+1683)*1+lsi)*1]), &(stack[((hsi*28+1591)*1+lsi)*1]), &(stack[((hsi*28+1655)*1+lsi)*1]), &(stack[((hsi*21+1570)*1+lsi)*1]), &(stack[((hsi*21+1549)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+1449)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_0[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_1[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+1452)*1+lsi)*1]), &(stack[((hsi*3+1449)*1+lsi)*1]), &(stack[((hsi*3+1431)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_0[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_1[vi]));
OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*10+1458)*1+lsi)*1]), &(stack[((hsi*6+1452)*1+lsi)*1]), &(stack[((hsi*6+1493)*1+lsi)*1]), &(stack[((hsi*3+1449)*1+lsi)*1]), &(stack[((hsi*3+1431)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__g__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*15+1478)*1+lsi)*1]), &(stack[((hsi*10+1458)*1+lsi)*1]), &(stack[((hsi*10+1499)*1+lsi)*1]), &(stack[((hsi*6+1452)*1+lsi)*1]), &(stack[((hsi*6+1493)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__h__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*21+1719)*1+lsi)*1]), &(stack[((hsi*15+1478)*1+lsi)*1]), &(stack[((hsi*15+1509)*1+lsi)*1]), &(stack[((hsi*10+1458)*1+lsi)*1]), &(stack[((hsi*10+1499)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__i__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*28+1740)*1+lsi)*1]), &(stack[((hsi*21+1719)*1+lsi)*1]), &(stack[((hsi*21+1570)*1+lsi)*1]), &(stack[((hsi*15+1478)*1+lsi)*1]), &(stack[((hsi*15+1509)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__k__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*36+1478)*1+lsi)*1]), &(stack[((hsi*28+1740)*1+lsi)*1]), &(stack[((hsi*28+1591)*1+lsi)*1]), &(stack[((hsi*21+1719)*1+lsi)*1]), &(stack[((hsi*21+1570)*1+lsi)*1]));
OSVRRP0InBra_aB_p__0__k__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*108+1768)*1+lsi)*1]), &(stack[((hsi*36+1478)*1+lsi)*1]), &(stack[((hsi*36+1683)*1+lsi)*1]), &(stack[((hsi*28+1591)*1+lsi)*1]));
_libint2_static_api_inc1_short_(&(stack[((hsi*108+0)*1+lsi)*1]),&(stack[((hsi*108+1768)*1+lsi)*1]),108);
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+1431)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_8[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_9[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+1570)*1+lsi)*1]), &(stack[((hsi*3+1428)*1+lsi)*1]), &(stack[((hsi*3+1431)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_7[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_8[vi]));
OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*10+1514)*1+lsi)*1]), &(stack[((hsi*6+1434)*1+lsi)*1]), &(stack[((hsi*6+1570)*1+lsi)*1]), &(stack[((hsi*3+1440)*1+lsi)*1]), &(stack[((hsi*3+1428)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__g__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*15+1576)*1+lsi)*1]), &(stack[((hsi*10+1468)*1+lsi)*1]), &(stack[((hsi*10+1514)*1+lsi)*1]), &(stack[((hsi*6+1443)*1+lsi)*1]), &(stack[((hsi*6+1434)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__h__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*21+1719)*1+lsi)*1]), &(stack[((hsi*15+1619)*1+lsi)*1]), &(stack[((hsi*15+1576)*1+lsi)*1]), &(stack[((hsi*10+1524)*1+lsi)*1]), &(stack[((hsi*10+1468)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__i__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*28+1440)*1+lsi)*1]), &(stack[((hsi*21+1634)*1+lsi)*1]), &(stack[((hsi*21+1719)*1+lsi)*1]), &(stack[((hsi*15+1534)*1+lsi)*1]), &(stack[((hsi*15+1619)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__k__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*36+1876)*1+lsi)*1]), &(stack[((hsi*28+1655)*1+lsi)*1]), &(stack[((hsi*28+1440)*1+lsi)*1]), &(stack[((hsi*21+1549)*1+lsi)*1]), &(stack[((hsi*21+1634)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__l__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*45+1524)*1+lsi)*1]), &(stack[((hsi*36+1683)*1+lsi)*1]), &(stack[((hsi*36+1876)*1+lsi)*1]), &(stack[((hsi*28+1591)*1+lsi)*1]), &(stack[((hsi*28+1655)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__l__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*45+1912)*1+lsi)*1]), &(stack[((hsi*36+1478)*1+lsi)*1]), &(stack[((hsi*36+1683)*1+lsi)*1]), &(stack[((hsi*28+1740)*1+lsi)*1]), &(stack[((hsi*28+1591)*1+lsi)*1]));
OSVRRP0InBra_aB_p__0__l__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*135+1957)*1+lsi)*1]), &(stack[((hsi*45+1912)*1+lsi)*1]), &(stack[((hsi*45+1524)*1+lsi)*1]), &(stack[((hsi*36+1683)*1+lsi)*1]));
_libint2_static_api_inc1_short_(&(stack[((hsi*135+108)*1+lsi)*1]),&(stack[((hsi*135+1957)*1+lsi)*1]),135);
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+1591)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_9[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_10[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+1740)*1+lsi)*1]), &(stack[((hsi*3+1431)*1+lsi)*1]), &(stack[((hsi*3+1591)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_8[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_9[vi]));
OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*10+1594)*1+lsi)*1]), &(stack[((hsi*6+1570)*1+lsi)*1]), &(stack[((hsi*6+1740)*1+lsi)*1]), &(stack[((hsi*3+1428)*1+lsi)*1]), &(stack[((hsi*3+1431)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__g__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*15+1604)*1+lsi)*1]), &(stack[((hsi*10+1514)*1+lsi)*1]), &(stack[((hsi*10+1594)*1+lsi)*1]), &(stack[((hsi*6+1434)*1+lsi)*1]), &(stack[((hsi*6+1570)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__h__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*21+1746)*1+lsi)*1]), &(stack[((hsi*15+1576)*1+lsi)*1]), &(stack[((hsi*15+1604)*1+lsi)*1]), &(stack[((hsi*10+1468)*1+lsi)*1]), &(stack[((hsi*10+1514)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__i__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*28+2092)*1+lsi)*1]), &(stack[((hsi*21+1719)*1+lsi)*1]), &(stack[((hsi*21+1746)*1+lsi)*1]), &(stack[((hsi*15+1619)*1+lsi)*1]), &(stack[((hsi*15+1576)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__k__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*36+2120)*1+lsi)*1]), &(stack[((hsi*28+1440)*1+lsi)*1]), &(stack[((hsi*28+2092)*1+lsi)*1]), &(stack[((hsi*21+1634)*1+lsi)*1]), &(stack[((hsi*21+1719)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__l__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*45+2156)*1+lsi)*1]), &(stack[((hsi*36+1876)*1+lsi)*1]), &(stack[((hsi*36+2120)*1+lsi)*1]), &(stack[((hsi*28+1655)*1+lsi)*1]), &(stack[((hsi*28+1440)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__m__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*55+1619)*1+lsi)*1]), &(stack[((hsi*45+1524)*1+lsi)*1]), &(stack[((hsi*45+2156)*1+lsi)*1]), &(stack[((hsi*36+1683)*1+lsi)*1]), &(stack[((hsi*36+1876)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__m__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*55+2201)*1+lsi)*1]), &(stack[((hsi*45+1912)*1+lsi)*1]), &(stack[((hsi*45+1524)*1+lsi)*1]), &(stack[((hsi*36+1478)*1+lsi)*1]), &(stack[((hsi*36+1683)*1+lsi)*1]));
OSVRRP0InBra_aB_p__0__m__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*165+2256)*1+lsi)*1]), &(stack[((hsi*55+2201)*1+lsi)*1]), &(stack[((hsi*55+1619)*1+lsi)*1]), &(stack[((hsi*45+1524)*1+lsi)*1]));
_libint2_static_api_inc1_short_(&(stack[((hsi*165+243)*1+lsi)*1]),&(stack[((hsi*165+2256)*1+lsi)*1]),165);
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+1428)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_10[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_11[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+1434)*1+lsi)*1]), &(stack[((hsi*3+1591)*1+lsi)*1]), &(stack[((hsi*3+1428)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_9[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_10[vi]));
OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*10+1468)*1+lsi)*1]), &(stack[((hsi*6+1740)*1+lsi)*1]), &(stack[((hsi*6+1434)*1+lsi)*1]), &(stack[((hsi*3+1431)*1+lsi)*1]), &(stack[((hsi*3+1591)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__g__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*15+1674)*1+lsi)*1]), &(stack[((hsi*10+1594)*1+lsi)*1]), &(stack[((hsi*10+1468)*1+lsi)*1]), &(stack[((hsi*6+1570)*1+lsi)*1]), &(stack[((hsi*6+1740)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__h__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*21+1478)*1+lsi)*1]), &(stack[((hsi*15+1604)*1+lsi)*1]), &(stack[((hsi*15+1674)*1+lsi)*1]), &(stack[((hsi*10+1514)*1+lsi)*1]), &(stack[((hsi*10+1594)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__i__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*28+1689)*1+lsi)*1]), &(stack[((hsi*21+1746)*1+lsi)*1]), &(stack[((hsi*21+1478)*1+lsi)*1]), &(stack[((hsi*15+1576)*1+lsi)*1]), &(stack[((hsi*15+1604)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__k__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*36+2421)*1+lsi)*1]), &(stack[((hsi*28+2092)*1+lsi)*1]), &(stack[((hsi*28+1689)*1+lsi)*1]), &(stack[((hsi*21+1719)*1+lsi)*1]), &(stack[((hsi*21+1746)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__l__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*45+2457)*1+lsi)*1]), &(stack[((hsi*36+2120)*1+lsi)*1]), &(stack[((hsi*36+2421)*1+lsi)*1]), &(stack[((hsi*28+1440)*1+lsi)*1]), &(stack[((hsi*28+2092)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__m__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*55+2502)*1+lsi)*1]), &(stack[((hsi*45+2156)*1+lsi)*1]), &(stack[((hsi*45+2457)*1+lsi)*1]), &(stack[((hsi*36+1876)*1+lsi)*1]), &(stack[((hsi*36+2120)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__ps__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*66+2557)*1+lsi)*1]), &(stack[((hsi*55+1619)*1+lsi)*1]), &(stack[((hsi*55+2502)*1+lsi)*1]), &(stack[((hsi*45+1524)*1+lsi)*1]), &(stack[((hsi*45+2156)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__ps__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*66+2623)*1+lsi)*1]), &(stack[((hsi*55+2201)*1+lsi)*1]), &(stack[((hsi*55+1619)*1+lsi)*1]), &(stack[((hsi*45+1912)*1+lsi)*1]), &(stack[((hsi*45+1524)*1+lsi)*1]));
OSVRRP0InBra_aB_p__0__ps__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*198+2689)*1+lsi)*1]), &(stack[((hsi*66+2623)*1+lsi)*1]), &(stack[((hsi*66+2557)*1+lsi)*1]), &(stack[((hsi*55+1619)*1+lsi)*1]));
_libint2_static_api_inc1_short_(&(stack[((hsi*198+408)*1+lsi)*1]),&(stack[((hsi*198+2689)*1+lsi)*1]),198);
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+1431)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_11[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_12[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+1499)*1+lsi)*1]), &(stack[((hsi*3+1428)*1+lsi)*1]), &(stack[((hsi*3+1431)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_10[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_11[vi]));
OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*10+1505)*1+lsi)*1]), &(stack[((hsi*6+1434)*1+lsi)*1]), &(stack[((hsi*6+1499)*1+lsi)*1]), &(stack[((hsi*3+1591)*1+lsi)*1]), &(stack[((hsi*3+1428)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__g__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*15+1876)*1+lsi)*1]), &(stack[((hsi*10+1468)*1+lsi)*1]), &(stack[((hsi*10+1505)*1+lsi)*1]), &(stack[((hsi*6+1740)*1+lsi)*1]), &(stack[((hsi*6+1434)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__h__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*21+1515)*1+lsi)*1]), &(stack[((hsi*15+1674)*1+lsi)*1]), &(stack[((hsi*15+1876)*1+lsi)*1]), &(stack[((hsi*10+1594)*1+lsi)*1]), &(stack[((hsi*10+1468)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__i__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*28+1440)*1+lsi)*1]), &(stack[((hsi*21+1478)*1+lsi)*1]), &(stack[((hsi*21+1515)*1+lsi)*1]), &(stack[((hsi*15+1604)*1+lsi)*1]), &(stack[((hsi*15+1674)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__k__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*36+1536)*1+lsi)*1]), &(stack[((hsi*28+1689)*1+lsi)*1]), &(stack[((hsi*28+1440)*1+lsi)*1]), &(stack[((hsi*21+1746)*1+lsi)*1]), &(stack[((hsi*21+1478)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__l__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*45+1891)*1+lsi)*1]), &(stack[((hsi*36+2421)*1+lsi)*1]), &(stack[((hsi*36+1536)*1+lsi)*1]), &(stack[((hsi*28+2092)*1+lsi)*1]), &(stack[((hsi*28+1689)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__m__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*55+2887)*1+lsi)*1]), &(stack[((hsi*45+2457)*1+lsi)*1]), &(stack[((hsi*45+1891)*1+lsi)*1]), &(stack[((hsi*36+2120)*1+lsi)*1]), &(stack[((hsi*36+2421)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__ps__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*66+2942)*1+lsi)*1]), &(stack[((hsi*55+2502)*1+lsi)*1]), &(stack[((hsi*55+2887)*1+lsi)*1]), &(stack[((hsi*45+2156)*1+lsi)*1]), &(stack[((hsi*45+2457)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__pp__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*78+2092)*1+lsi)*1]), &(stack[((hsi*66+2557)*1+lsi)*1]), &(stack[((hsi*66+2942)*1+lsi)*1]), &(stack[((hsi*55+1619)*1+lsi)*1]), &(stack[((hsi*55+2502)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__pp__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*78+3008)*1+lsi)*1]), &(stack[((hsi*66+2623)*1+lsi)*1]), &(stack[((hsi*66+2557)*1+lsi)*1]), &(stack[((hsi*55+2201)*1+lsi)*1]), &(stack[((hsi*55+1619)*1+lsi)*1]));
OSVRRP0InBra_aB_p__0__pp__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*234+3086)*1+lsi)*1]), &(stack[((hsi*78+3008)*1+lsi)*1]), &(stack[((hsi*78+2092)*1+lsi)*1]), &(stack[((hsi*66+2557)*1+lsi)*1]));
_libint2_static_api_inc1_short_(&(stack[((hsi*234+606)*1+lsi)*1]),&(stack[((hsi*234+3086)*1+lsi)*1]),234);
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+1572)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_12[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_13[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+1575)*1+lsi)*1]), &(stack[((hsi*3+1431)*1+lsi)*1]), &(stack[((hsi*3+1572)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_11[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_12[vi]));
OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*10+1581)*1+lsi)*1]), &(stack[((hsi*6+1499)*1+lsi)*1]), &(stack[((hsi*6+1575)*1+lsi)*1]), &(stack[((hsi*3+1428)*1+lsi)*1]), &(stack[((hsi*3+1431)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__g__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*15+2170)*1+lsi)*1]), &(stack[((hsi*10+1505)*1+lsi)*1]), &(stack[((hsi*10+1581)*1+lsi)*1]), &(stack[((hsi*6+1434)*1+lsi)*1]), &(stack[((hsi*6+1499)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__h__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*21+1936)*1+lsi)*1]), &(stack[((hsi*15+1876)*1+lsi)*1]), &(stack[((hsi*15+2170)*1+lsi)*1]), &(stack[((hsi*10+1468)*1+lsi)*1]), &(stack[((hsi*10+1505)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__i__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*28+1591)*1+lsi)*1]), &(stack[((hsi*21+1515)*1+lsi)*1]), &(stack[((hsi*21+1936)*1+lsi)*1]), &(stack[((hsi*15+1674)*1+lsi)*1]), &(stack[((hsi*15+1876)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__k__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*36+2185)*1+lsi)*1]), &(stack[((hsi*28+1440)*1+lsi)*1]), &(stack[((hsi*28+1591)*1+lsi)*1]), &(stack[((hsi*21+1478)*1+lsi)*1]), &(stack[((hsi*21+1515)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__l__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*45+1619)*1+lsi)*1]), &(stack[((hsi*36+1536)*1+lsi)*1]), &(stack[((hsi*36+2185)*1+lsi)*1]), &(stack[((hsi*28+1689)*1+lsi)*1]), &(stack[((hsi*28+1440)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__m__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*55+1664)*1+lsi)*1]), &(stack[((hsi*45+1891)*1+lsi)*1]), &(stack[((hsi*45+1619)*1+lsi)*1]), &(stack[((hsi*36+2421)*1+lsi)*1]), &(stack[((hsi*36+1536)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__ps__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*66+3320)*1+lsi)*1]), &(stack[((hsi*55+2887)*1+lsi)*1]), &(stack[((hsi*55+1664)*1+lsi)*1]), &(stack[((hsi*45+2457)*1+lsi)*1]), &(stack[((hsi*45+1891)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__pp__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*78+2421)*1+lsi)*1]), &(stack[((hsi*66+2942)*1+lsi)*1]), &(stack[((hsi*66+3320)*1+lsi)*1]), &(stack[((hsi*55+2502)*1+lsi)*1]), &(stack[((hsi*55+2887)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__pd__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*91+3386)*1+lsi)*1]), &(stack[((hsi*78+2092)*1+lsi)*1]), &(stack[((hsi*78+2421)*1+lsi)*1]), &(stack[((hsi*66+2557)*1+lsi)*1]), &(stack[((hsi*66+2942)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__pd__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*91+3477)*1+lsi)*1]), &(stack[((hsi*78+3008)*1+lsi)*1]), &(stack[((hsi*78+2092)*1+lsi)*1]), &(stack[((hsi*66+2623)*1+lsi)*1]), &(stack[((hsi*66+2557)*1+lsi)*1]));
OSVRRP0InBra_aB_p__0__pd__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*273+3568)*1+lsi)*1]), &(stack[((hsi*91+3477)*1+lsi)*1]), &(stack[((hsi*91+3386)*1+lsi)*1]), &(stack[((hsi*78+2092)*1+lsi)*1]));
_libint2_static_api_inc1_short_(&(stack[((hsi*273+840)*1+lsi)*1]),&(stack[((hsi*273+3568)*1+lsi)*1]),273);
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+1428)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_13[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_14[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+1434)*1+lsi)*1]), &(stack[((hsi*3+1572)*1+lsi)*1]), &(stack[((hsi*3+1428)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_12[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_13[vi]));
OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*10+2499)*1+lsi)*1]), &(stack[((hsi*6+1575)*1+lsi)*1]), &(stack[((hsi*6+1434)*1+lsi)*1]), &(stack[((hsi*3+1431)*1+lsi)*1]), &(stack[((hsi*3+1572)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__g__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*15+2509)*1+lsi)*1]), &(stack[((hsi*10+1581)*1+lsi)*1]), &(stack[((hsi*10+2499)*1+lsi)*1]), &(stack[((hsi*6+1499)*1+lsi)*1]), &(stack[((hsi*6+1575)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__h__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*21+2524)*1+lsi)*1]), &(stack[((hsi*15+2170)*1+lsi)*1]), &(stack[((hsi*15+2509)*1+lsi)*1]), &(stack[((hsi*10+1505)*1+lsi)*1]), &(stack[((hsi*10+1581)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__i__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*28+2545)*1+lsi)*1]), &(stack[((hsi*21+1936)*1+lsi)*1]), &(stack[((hsi*21+2524)*1+lsi)*1]), &(stack[((hsi*15+1876)*1+lsi)*1]), &(stack[((hsi*15+2170)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__k__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*36+2573)*1+lsi)*1]), &(stack[((hsi*28+1591)*1+lsi)*1]), &(stack[((hsi*28+2545)*1+lsi)*1]), &(stack[((hsi*21+1515)*1+lsi)*1]), &(stack[((hsi*21+1936)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__l__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*45+2609)*1+lsi)*1]), &(stack[((hsi*36+2185)*1+lsi)*1]), &(stack[((hsi*36+2573)*1+lsi)*1]), &(stack[((hsi*28+1440)*1+lsi)*1]), &(stack[((hsi*28+1591)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__m__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*55+2499)*1+lsi)*1]), &(stack[((hsi*45+1619)*1+lsi)*1]), &(stack[((hsi*45+2609)*1+lsi)*1]), &(stack[((hsi*36+1536)*1+lsi)*1]), &(stack[((hsi*36+2185)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__ps__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*66+1428)*1+lsi)*1]), &(stack[((hsi*55+1664)*1+lsi)*1]), &(stack[((hsi*55+2499)*1+lsi)*1]), &(stack[((hsi*45+1891)*1+lsi)*1]), &(stack[((hsi*45+1619)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__pp__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*78+2499)*1+lsi)*1]), &(stack[((hsi*66+3320)*1+lsi)*1]), &(stack[((hsi*66+1428)*1+lsi)*1]), &(stack[((hsi*55+2887)*1+lsi)*1]), &(stack[((hsi*55+1664)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__pd__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*91+1428)*1+lsi)*1]), &(stack[((hsi*78+2421)*1+lsi)*1]), &(stack[((hsi*78+2499)*1+lsi)*1]), &(stack[((hsi*66+2942)*1+lsi)*1]), &(stack[((hsi*66+3320)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__pf__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*105+1519)*1+lsi)*1]), &(stack[((hsi*91+3386)*1+lsi)*1]), &(stack[((hsi*91+1428)*1+lsi)*1]), &(stack[((hsi*78+2092)*1+lsi)*1]), &(stack[((hsi*78+2421)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__pf__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*105+2421)*1+lsi)*1]), &(stack[((hsi*91+3477)*1+lsi)*1]), &(stack[((hsi*91+3386)*1+lsi)*1]), &(stack[((hsi*78+3008)*1+lsi)*1]), &(stack[((hsi*78+2092)*1+lsi)*1]));
OSVRRP0InBra_aB_p__0__pf__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*315+3841)*1+lsi)*1]), &(stack[((hsi*105+2421)*1+lsi)*1]), &(stack[((hsi*105+1519)*1+lsi)*1]), &(stack[((hsi*91+3386)*1+lsi)*1]));
_libint2_static_api_inc1_short_(&(stack[((hsi*315+1113)*1+lsi)*1]),&(stack[((hsi*315+3841)*1+lsi)*1]),315);
}
}
}
const int hsi = 0;
const int lsi = 0;
const int vi = 0;
/** Number of flops = 1428 */
}

#ifdef __cplusplus
};
#endif
